@@ -1,9 +1,9 @@
 /*
 **  OSSP al - Assembly Line
-**  Copyright (c) 2002 Ralf S. Engelschall <rse@engelschall.com>
-**  Copyright (c) 2002 The OSSP Project <http://www.ossp.org/>
-**  Copyright (c) 2002 Cable & Wireless Deutschland <http://www.cw.com/de/>
-**  Copyright (c) 2002 Michael van Elst <mlelstv@dev.de.cw.net>
+**  Copyright (c) 2002-2005 Ralf S. Engelschall <rse@engelschall.com>
+**  Copyright (c) 2002-2005 The OSSP Project <http://www.ossp.org/>
+**  Copyright (c) 2002-2005 Cable & Wireless <http://www.cw.com/>
+**  Copyright (c) 2002-2005 Michael van Elst <mlelstv@serpens.de>
 **
 **  This file is part of OSSP al, an abstract datatype of a data buffer
 **  that can assemble, move and truncate data but avoids actual copying
@@ -54,14 +54,14 @@ static char label, label2, label3;
     block \
     if (rc != rc0) \
         ts_test_fail(TS_CTX, "%s -> %d[%s] (expected %d[%s])\n", \
-            rc, al_error(rc), rc0, al_error(rc0))
+            name, rc, al_error(rc), rc0, al_error(rc0))
 
 #define CHECKLEN(name, al) \
     do { \
         size_t good, bad; \
         if (checklen(al, &good, &bad)) \
             ts_test_fail(TS_CTX, "%s -> corrupted length %d (expected %d)\n", \
-                good, bad); \
+                name, good, bad); \
     } while (0)
 
 #define EVAL0(name,block) EVAL(name,rc,AL_OK,block)
